@@ -2,7 +2,7 @@ package Web::Hippie;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 use parent 'Plack::Middleware';
 
 use Plack::Util::Accessor qw( root init on_error on_message trusted_origin );
@@ -156,7 +156,7 @@ sub handler_ws {
             return [403, ['Content-Type' => 'text/plain'], ['origin not allowed']];
         }
 
-
+        my $ws = $env->{HTTPS} ? 'wss' : 'ws';
         return sub {
             my $respond = shift;
             my $protocol = $env->{HTTP_SEC_WEBSOCKET_PROTOCOL};
@@ -166,7 +166,7 @@ sub handler_ws {
                 "Upgrade: WebSocket",
                 "Connection: Upgrade",
                 "Sec-WebSocket-Origin: $env->{HTTP_ORIGIN}",
-                "Sec-WebSocket-Location: ws://$env->{HTTP_HOST}$request_uri",
+                "Sec-WebSocket-Location: $ws://$env->{HTTP_HOST}$request_uri",
                 ($protocol ? "Sec-WebSocket-Protocol: $protocol" : ()),
                 '', '';
 
